pub enum Bottleneck {
ComputeBound,
MemoryBound,
}Expand description
Whether an operation is bottlenecked by compute or memory bandwidth.
Variants
ComputeBound
FLOPs exceed what can be hidden by memory latency.
MemoryBound
Memory traffic exceeds what can be hidden by compute.