estimate_kernel_cost

Function estimate_kernel_cost 

pub fn estimate_kernel_cost(pattern: &KernelPattern) -> OpCost
Estimate the compute and memory cost of a classified kernel pattern.

Element size defaults to 4 bytes (f32) unless the pattern provides enough information to determine otherwise.